# MkDocs Mini Blog

[![Documentation](https://github.com/dpoulopoulos/mkdocs-mini-blog/actions/workflows/documentation.yml/badge.svg)](https://github.com/dpoulopoulos/mkdocs-mini-blog/actions/workflows/documentation.yml)
[![Publish to PyPI](https://github.com/dpoulopoulos/mkdocs-mini-blog/actions/workflows/release.yml/badge.svg)](https://github.com/dpoulopoulos/mkdocs-mini-blog/actions/workflows/release.yml)


Mini Blog is a theme for [MkDocs](https://www.mkdocs.org/), a static site generator that's geared towards building
project documentation. Follow the instructions below to install and activate the theme. For full documentation visit the
project's documentation site.

## Install

To install MkDocs, run the following command from the command line:

```bash
pip install mkdocs
```

Then, install the theme using PIP:

```bash
pip install mkdocs-mini-blog
```

## Activating theme

After the theme is installed, edit your `mkdocs.yml` file and set the theme name to `mini-blog`:

```yml
theme:
    name: mini-blog
```

## Getting Help

We use GitHub issues for tracking bugs and feature requests and have limited bandwidth to address them. If you need
anything, I ask you to please follow our templates for opening issues or discussions.

- 🐛 [Bug Report](https://github.com/dpoulopoulos/mkdocs-mini-blog/issues/new)
- 📕 [Documentation Issue](https://github.com/dpoulopoulos/mkdocs-mini-blog/issues/new)
- 🚀 [Feature Request](https://github.com/dpoulopoulos/mkdocs-mini-blog/issues/new)
- 💬 [General Question](https://github.com/dpoulopoulos/mkdocs-mini-blog/issues/new)

## License
![GitHub License](https://img.shields.io/github/license/dpoulopoulos/mkdocs-mini-blog)

This project is licensed under the terms of the MIT License.
